# 入门指南

欢迎使用 TuFT！本节将帮助您快速上手。

```{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card} 安装指南
:link: installation
:link-type: doc
:shadow: none

从源码、PyPI 或 Docker 安装 TuFT。
:::

:::{grid-item-card} 快速开始
:link: quickstart
:link-type: doc
:shadow: none

使用 TuFT 运行您的第一个训练与推理示例。
:::
```

```{toctree}
:maxdepth: 1
:hidden:

installation
quickstart
```
